## ----style, echo=FALSE--------------------------------------------------------
knitr::opts_chunk$set(error=FALSE, warning=FALSE, message=FALSE,
    fig.retina = 0.75)
library(BiocStyle)

## ----library, echo=FALSE, results='hide'--------------------------------------
suppressPackageStartupMessages(c(
    library(SingleCellExperiment),
    library(cytomapper),
    library(imcdatasets)
))

## ----list-datasets------------------------------------------------------------
datasets <- listDatasets()
datasets <- as.data.frame(datasets)
datasets$FunctionCall <- sprintf("`%s`", datasets$FunctionCall)
knitr::kable(datasets)

## ----import-dataset-----------------------------------------------------------
sce <- Damond_2019_Pancreas("sce")
sce

## ----import-images------------------------------------------------------------
images <- Damond_2019_Pancreas("images")
images

## ----import-masks-------------------------------------------------------------
masks <- Damond_2019_Pancreas("masks")
masks

## ----on_disk------------------------------------------------------------------
# Create temporary location
cur_path <- tempdir()

masks <- Damond_2019_Pancreas(data_type = "masks", on_disk = TRUE,
    h5FilesPath = cur_path)
masks

## ----function-help------------------------------------------------------------
?Damond_2019_Pancreas

## ----access-metadata, eval = FALSE--------------------------------------------
#  Damond_2019_Pancreas(data_type = "sce", metadata = TRUE)
#  Damond_2019_Pancreas(data_type = "images", metadata = TRUE)
#  Damond_2019_Pancreas(data_type = "masks", metadata = TRUE)

## ----usage-subset-------------------------------------------------------------
cur_images <- images[1:5]
cur_masks <- masks[1:5]

## ----usage-pixel--------------------------------------------------------------
plotPixels(
    cur_images,
    colour_by = c("CDH1", "CD99", "H3"),
    bcg = list(
        CD99 = c(0,2,1),
        CDH1 = c(0,8,1),
        H3 = c(0,5,1)
    )
)

## ----usage-cell---------------------------------------------------------------
plotCells(
    cur_masks, object = sce,
    img_id = "image_number", cell_id = "cell_number",
    colour_by = c("CD8a", "PIN"),
    exprs_values = "exprs"
)

## ----usage-outline------------------------------------------------------------
plotPixels(
    cur_images, mask = cur_masks, object = sce,
    img_id = "image_number", cell_id = "cell_number",
    outline_by = "cell_type",
    colour_by = c("H3", "CD99", "CDH1"),
    bcg = list(
        CD99 = c(0,2,1),
        CDH1 = c(0,8,1),
        H3 = c(0,5,1)
    )
)

## ----sessionInfo, echo=FALSE--------------------------------------------------
sessionInfo()

